import { Relationship } from "../../svi-datahub";
import { MapBoundedBoxFilter, MapBoundedPolygonFilter, MapRadiusFilter, MapShapeFilter, QueryMode, SearchRepresentation, SearchResponse } from "../../svi-sand";
import { ObjectIdentifier } from "../../object/object-api";
import { QueryBuilderModel, SearchApi } from "../search-api";
export declare enum SearchVisualization {
    Summary = "summary",
    Map = "map",
    Table = "table"
}
export declare enum Visualization {
    Summary = "summary",
    Map = "map",
    Table = "table",
    Timeline = "timeline",
    Network = "network"
}
export declare type MapFilter = MapBoundedPolygonFilter | MapRadiusFilter | MapBoundedBoxFilter | MapShapeFilter;
export interface SearchQuery {
    additionalModes?: string[];
    queryText: string;
    visualizationName?: Visualization;
}
export interface NetworkData {
    nodes: Array<{
        type: string;
        id: string;
    }>;
    links: Array<{
        source: string;
        target: string;
        id: string;
        type: string;
    }>;
    options: {
        showLinkLabels?: boolean;
        showNodeAnnotation?: boolean;
        showNodeLabels?: boolean;
        showTimeline?: boolean;
        showTransactionDetails?: boolean;
        showTransactionLinks?: boolean;
    };
}
export interface ResolvedObjectIdentifier extends ObjectIdentifier {
    compoundValues: string[];
}
export interface SearchAndCreateDialogModel {
    entityName: string;
    entityLabel: string;
    relateToParentName?: string;
    relateToParentLabel?: string;
    canCreate?: boolean;
    linkReasons?: Relationship[];
}
export interface SearchObject extends ObjectIdentifier {
    title?: string;
    isResolvedEntity?: boolean;
    typeLabel?: string;
    uniqueKey?: string;
    compoundValues?: string[];
}
export interface SearchAndCreateRelateToModel {
    linkReason?: Relationship;
    relateToTargetId?: string;
    relateToTargetType?: string;
}
export interface SearchAndCreateResponse {
    selectedItem?: SearchObject;
    relateToModel?: SearchAndCreateRelateToModel;
}
/**
 * {@link SearchApi} extension pertains to functionality related to SAS Visual Investigators search capabilities.
 * These additional methods are available only in the SAS Visual Investigator Client Application.
 * Accessed from the window at window.sas.vi.search.
 * @extends SearchApi
 */
export interface ClientSearchApi extends SearchApi {
    /**
     * @method
     * @description Performs a search against the svi-sand service.
     * @param query {SearchRepresentation} Query to send to the service.
     * @returns A promise containing the search response.
     */
    performSearch(query: SearchRepresentation): Promise<SearchResponse>;
    /**
     * @method
     * @description Performs a search against the svi-sand service and navigates the user to the Search Results page.
     * @param queryText {string} Text used to form the query.
     * @param visualizationName {"summary" | "map" | "table"} Visualization to query for and then display to the user.
     * @param [mapFilters] {MapFilter[]} The map filter object to include with the search query. This can consist of MapBoundedPolygonFilter, MapRadiusFilter, MapBoundedBoxFilter or MapShapeFilter.
     * @param [queryMode] {"standard" | "phonetic" | "synonym"} Used to perform phonetic and synonym searches. Default is "standard".
     */
    navigateSearch(queryText: string, visualizationName: SearchVisualization, mapFilters?: MapFilter[], queryMode?: QueryMode[]): Promise<void>;
    /**
     * @method
     * @description Gets the current search query if one exists. Otherwise undefined.
     */
    getCurrentSearchQuery(): SearchQuery | undefined;
    /**
     * @method
     * @description Converts a query model generated by the query builder to a string.
     * @param queryModel {QueryBuilderModel} Query builder model.
     * @returns A promise containing the string representation of the query.
     */
    createQueryStringFromModel(queryModel: QueryBuilderModel): Promise<string>;
    /**
     * @method
     * @description Gets the query builder model for the given ID. If no ID is given, it returns the query model for SEARCH.
     * @param [id] {string} ID of the model to get. Defaults to SEARCH.
     * @returns A query builder model.
     */
    getQueryBuilderModel(id?: string): QueryBuilderModel | undefined;
    /**
     * @method
     * @description Sets the query builder model for the given ID. If no ID is given, it sets the query model for SEARCH.
     * Once stored, the query model is used to initially populate a Query Builder opened with the given ID.
     * @param queryModel {QueryBuilderModel} A query builder model.
     * @param [id] {string} ID of the model to set. Defaults to SEARCH.
     */
    setQueryBuilderModel(queryModel: QueryBuilderModel, id?: string): void;
    /**
     * @method
     * @description Opens up the "Add Objects to Workspace" dialog box and then performs the action once a document and workspace have been selected.
     * @param visualizationName {Visualization} Visualization to initially display once the objects have been added.
     * @param objects {Array<ObjectIdentifier | ResolvedObjectIdentifier>} Objects to add to the workspace.
     * @param [currentObject] {ObjectIdentifier} The document the user is currently viewing. This is used as a visual aid in the dialog box.
     * @param [networkData] {NetworkData} Network visualization data to be copied to the workspace.
     */
    openAddObjectsToWorkspaceDialog(visualizationName: Visualization, objects: Array<ObjectIdentifier | ResolvedObjectIdentifier>, currentObject?: ObjectIdentifier, networkData?: NetworkData): Promise<void>;
    /**
     * @method
     * @description Adds an image to the Insights selected in the "Add image to Insights" dialog box.
     * @param imageData {Uint8Array} Image to add.
     * @param contentType {string} This is used in the content-type header when the file is uploaded. For example 'image/png'.
     * @param [height] {string} Height of the Insights cell.
     * @param [width] {string} Width of the Insights cell.
     */
    openAddImageToInsightsDialog(imageData: Uint8Array, contentType: string, height?: string, width?: string): Promise<void>;
    /**
     * @method
     * @description Creates a new workspace in the target object, populating it with an initial set of objects.
     * Allows the creation of new objects assuming create mode is supported for the object type.
     * @param objectsToAdd {Array<ObjectIdentifier | ResolvedObjectIdentifier>} Objects to add to the workspace.
     * @param targetObjectType {string} Object type where the workspace is created.
     * @param [targetObjectId] {string} Object to add to the workspace. If undefined, a new object is created.
     * @param [visualization] {"summary" | "map" | "table" | "timeline" | "network"} Visualization to initially display in the new workspace.
     * @param [workspaceName] {string} Name of the new workspace.
     * @param [networkData] {NetworkData} Network visualization data to be copied to the new workspace.
     */
    addToNewWorkspace(objectsToAdd: Array<ObjectIdentifier | ResolvedObjectIdentifier>, targetObjectType: string, targetObjectId?: string, visualization?: Visualization, workspaceName?: string, networkData?: NetworkData): Promise<void>;
    /**
     * @method
     * @description Launches a wizard allowing users to search first, before creating an object/relationship.
     * Relationship wizard is determined by relateToParentLabel or relateToParentName being defined within the wizardValues parameter.
     * @param wizardValues {SearchAndCreateDialogModel} Object containing entity and relationship data.
     * @param [onRelationshipSuccess] {function} A callback function that is defined when creating a relationship.
     * It is invoked when a relationship is saved successfully.
     */
    openSearchAndCreateDialog(wizardValues: SearchAndCreateDialogModel, onRelationshipSuccess?: () => void): Promise<SearchAndCreateResponse>;
}
